﻿using Microsoft.AspNetCore.Components;
using System.Collections.Generic;
using System.Threading.Tasks;
using Blazorise.DataGrid;
using UserService.DatabaseLayer.DataModels;
using UserService.DatabaseLayer.Repository;

namespace UserService.Pages
{
    public class UsersBase : ComponentBase
    {
        [Inject] private IUsersRepository UsersRepository { get; set; } = null!;
        [Inject] private IOrganizationUnitsRepository OrganizationUnitsRepository { get; set; } = null!;

        protected bool DialogIsOpen { get; set; }
        protected User? UserToEdit { get; private set; }

        protected IReadOnlyList<User>? Users { get; private set; }
        protected IReadOnlyList<OrganizationUnit>? OrganizationUnits { get; private set; }

        protected override async Task OnInitializedAsync()
        {
            Users = await UsersRepository.GetAllAsync();
            OrganizationUnits = await OrganizationUnitsRepository.GetAllAsync().ConfigureAwait(false);
        }

        protected void EditUser(User user)
        {
            DialogIsOpen = true;
            UserToEdit = user;
        }

        protected async Task OkClick()
        {
            if (UserToEdit is null) return;
            await UsersRepository.UpdateAsync(UserToEdit).ConfigureAwait(false);
            DialogIsOpen = false;
        }

        protected async Task DeleteUser(User user)
        {
            await UsersRepository.DeleteAsync(user).ConfigureAwait(false);
        }

        protected async Task RowInsertedCallback(SavedRowItem<User, Dictionary<string, object>> obj)
        {
            var user = obj.Item;
            user.ParentId = -2;
            await UsersRepository.AddAsync(user);
        }
    }
}